<?xml version="1.0"?>
<xsl:stylesheet xmlns:xsl="http://www.w3.org/1999/XSL/Transform" xmlns:ms="urn:schemas-microsoft-com:xslt" xmlns:vb="urn:the-xml-files:xslt-vb" xmlns:js="urn:the-xml-files:xslt-js" version="1.0">
	<xsl:output method="html"/>
	<xsl:param name="AffectedCategory"/>
	<xsl:include href="LocaleIndependent.inc"/>
	<xsl:include href="WeekProcessing.inc"/>
	<xsl:include href="PlanEntryProcessing.inc"/>
	<xsl:include href="Common.inc"/>
	<xsl:include href="HolidaysProcessing.inc"/>
	<xsl:include href="ActivitiesProcessing.inc"/>
	<xsl:include href="Intending.inc"/>
	<xsl:include href="Subprojects.inc"/>
	<xsl:include href="ReportCSS.inc"/>
	<xsl:key name="task_key" match="//DAY/PLANENTRY" use="@TASKID"/>
	<xsl:key name="task_day_key" match="//DAY" use="PLANENTRY/@TASKID"/>
	<xsl:template match="/">
		<xsl:value-of select="vb:PushHolidays(//HOLIDAYS/HOLIDAY/@DATE)"/>
		<xsl:variable name="projectTitle">
			<xsl:if test="$AffectedCategory != 0">
			<xsl:for-each select="//CATEGORY[@ID=$AffectedCategory]">
				<xsl:value-of select="@NAME"/>
			</xsl:for-each>
			</xsl:if>
			<xsl:if test="$AffectedCategory = 0">
			{AllTasks}
			</xsl:if>
			- <xsl:value-of select="vb:GetCurrentDate()"/>
		</xsl:variable>
		<xsl:variable name="parentProjectTitle"> 
			<xsl:for-each select="//CATEGORY[@ID=$AffectedCategory]"> 
			<xsl:value-of select="vb:GetParentNames(.)"/>
			<xsl:value-of select="@NAME"/>
			</xsl:for-each> 
			<xsl:if test="$AffectedCategory = 0">
			{AllTasks}
			</xsl:if>
		</xsl:variable>
		<HTML>
			<HEAD>
				<TITLE>{Report}: {ProjectActivity} (<xsl:value-of select="$projectTitle"/>)</TITLE>
				<META NAME="Report" CONTENT="{ProjectActivity}"/>
				<STYLE ID="ReportStyle">
				<xsl:value-of select="$css"/>
				</STYLE>
			</HEAD>
			<BODY>
				<H2>{ProjectActivity}</H2>
				<xsl:for-each select="//PROPERTIES">
					<table border="0" cellpadding="2" cellspacing="0">
						<tr>
						<td class="righttitle">{Employee}: </td>
						<td class="underlined"><xsl:value-of select="@AUTHOR"/></td>
						</tr>
						<tr>
						<td class="righttitle">{Category}: </td>
						<td class="underlined"><xsl:value-of select="$parentProjectTitle"/></td>
						</tr>
						<tr>
						<td class="righttitle">{Date}: </td>
						<td class="underlined"><xsl:value-of select="vb:GetCurrentDate()"/></td>
						</tr>
					</table>
				</xsl:for-each>

				<br/>
				<TABLE BORDER="0" CELLPADDING="2" CELLSPACING="0" WIDTH="100%">
					<THEAD style="display: table-header-group">
					<TR>
						<TD class="leftHeadCell">{Name}</TD>
						<TD class="headCell">{TimeDeclared} ({hours})</TD>
						<TD class="headCell">{ReallySpent} ({hours})</TD>
						<TD class="headCell">{Deadline}</TD>
						<TD class="headCell">{CompletedAt}</TD>
					</TR>
					</THEAD>
					<TBODY>
					<xsl:choose>
					<xsl:when test="$AffectedCategory != 0">
					<xsl:for-each select="//CATEGORY[@ID=$AffectedCategory]">
						<xsl:value-of select="vb:SetBaseIntend(vb:GetIntend(.))"/>
						<xsl:apply-templates select="."/>
					</xsl:for-each>
					</xsl:when>
					<xsl:otherwise>
					<xsl:for-each select="ROOT/CATEGORY">
						<xsl:value-of select="vb:SetBaseIntend('')"/>
						<xsl:apply-templates select="."/>
					</xsl:for-each>
					</xsl:otherwise>
					</xsl:choose>
					</TBODY>
				</TABLE>

				<BR/>

				<table border="0" cellpadding="2" cellspacing="0">
				<tr><td colspan="2">&#160; </td></tr>
				<tr><td colspan="2">&#160; </td></tr>
				<tr>
				<td class="signetureCell" style="width: 300">{EmployeeSignature}</td>
				<td class="signetureCell">{Date}</td>
				</tr>
				<tr><td colspan="2">&#160; </td></tr>
				<tr>
				<td class="signetureCell">{ManagerSignature}</td>
				<td class="signetureCell">{Date}</td>
				</tr>
				</table>

			</BODY>
		</HTML>
	</xsl:template>
	<xsl:template match="CATEGORY">
		<xsl:variable name="categoryId" select="@ID"/>
		<xsl:variable name="estimatesCat" select="sum(.//TASK/@ESTIMATION)"/>
		<xsl:variable name="catDeadline" select="vb:GetMaxDate(.//TASK/@DEADLINE)"/>
		<xsl:variable name="catPlanEntriesList" select="//DAY/PLANENTRY[@TASKID=//CATEGORY[@ID=$categoryId]//TASK/@ID]"/>
		<xsl:variable name="stageWorkingHours" select="vb:CalculateHours($catPlanEntriesList)"/>
		<xsl:variable name="catPlanEntriesDaysList" select="//DAY[PLANENTRY/@TASKID=//CATEGORY[@ID=$categoryId]//TASK/@ID]"/>
		<xsl:variable name="catLastPlanEntryDate" select="vb:GetLastPlanEntryDate($catPlanEntriesDaysList)"/>

		<xsl:if test=".//TASK">
			<TR>
				<TD class="categoryCell">
					<xsl:value-of select="vb:GetIntend(.)"/>
					<xsl:value-of select="@NAME"/>
				</TD>
				<TD class="categoryTotal">
					<xsl:value-of select="vb:FormatNumberEx(js:ToDbl($estimatesCat))"/>
				</TD>
				<TD class="categoryTotal">
					<xsl:value-of select="$stageWorkingHours"/>
				</TD>
				<TD class="categoryTotal">
					<xsl:value-of select="$catDeadline"/>
				</TD>
				<TD class="categoryTotal">
					<xsl:if test="not(.//TASK/@STATUS &lt; 2)">
						<xsl:value-of select="vb:FormatDate($catLastPlanEntryDate)"/>
					</xsl:if>&#160;
				</TD>
			</TR>
			<xsl:if test="./TASK">
				<xsl:for-each select="./TASK">
					<xsl:sort select="@DEADLINE"/>
					<xsl:sort select="@STATUS" order="ascending"/>
					<xsl:sort select="@IMPORTANCE"/>
					<xsl:sort select="@NAME"/>
					<xsl:apply-templates select="."/>
				</xsl:for-each>
			</xsl:if>
			<xsl:if test="./CATEGORY">
				<xsl:if test=".//TASK">
					<xsl:for-each select="./CATEGORY">
						<xsl:sort select="@NAME"/>
						<xsl:apply-templates select="."/>
					</xsl:for-each>
				</xsl:if>
			</xsl:if>
		</xsl:if>
	</xsl:template>
	<xsl:template match="TASK">
		<xsl:variable name="id" select="@ID"/>
		<xsl:variable name="planEntriesList" select="key('task_key', $id)"/>
		<xsl:variable name="planEntriesDaysList" select="key('task_day_key', $id)"/>
		<xsl:variable name="nPlanEntries" select="count($planEntriesList)"/>
		<xsl:variable name="workingHours" select="vb:CalculateHours($planEntriesList)"/>
		<xsl:variable name="lastPlanEntryDate" select="vb:GetLastPlanEntryDate($planEntriesDaysList)"/>
		<xsl:variable name="firstPlanEntryDate" select="vb:GetFirstPlanEntryDate($planEntriesDaysList)"/>
		<xsl:variable name="tempPushDates" select="vb:PushPlanEntryDates($firstPlanEntryDate, $lastPlanEntryDate, string(@STATUS))"/>
		<xsl:variable name="tempPushHours" select="vb:PushHours($workingHours, js:ToDbl(string(@ESTIMATION)), string(@STATUS))"/>

		<xsl:value-of select="$tempPushHours"/>
		<TR>
			<TD class="taskCell">
				<xsl:value-of select="vb:GetRecentIntend()"/><xsl:value-of select="@NAME"/>
			</TD>
			<TD class="freeTableCell">
				<xsl:value-of select="vb:FormatNumberEx(js:ToDbl(string(@ESTIMATION)))"/>
			</TD>
			<TD class="freeTableCell">
				<xsl:value-of select="$workingHours"/>
			</TD>
			<TD class="freeTableCell">
				<xsl:value-of select="vb:FormatDate(string(@DEADLINE))"/>
			</TD>
			<TD class="freeTableCell">
				<xsl:if test="@STATUS=2">
					<xsl:value-of select="vb:FormatDate($lastPlanEntryDate)"/>
				</xsl:if>&#160;
			</TD>
		</TR>
	</xsl:template>
</xsl:stylesheet>
