<?xml version="1.0"?>
<xsl:stylesheet xmlns:xsl="http://www.w3.org/1999/XSL/Transform" xmlns:ms="urn:schemas-microsoft-com:xslt" xmlns:vb="urn:the-xml-files:xslt-vb" xmlns:js="urn:the-xml-files:xslt-js" version="1.0">
	<xsl:output method="html"/>
	<xsl:param name="AffectedCategory"/>
	<xsl:param name="ReportingPeriodStart"/>
	<xsl:param name="ReportingPeriodEnd"/>
	<xsl:include href="Common.inc"/>
	<xsl:include href="LocaleIndependent.inc"/>
	<xsl:include href="WeekProcessing.inc"/>
	<xsl:include href="PlanEntryProcessing.inc"/>
  <xsl:include href="DayTimeProcessing.inc"/>
	<xsl:include href="Intending.inc"/>
	<xsl:include href="Subprojects.inc"/>
	<xsl:include href="ReportCSS.inc"/>
	<xsl:key name="task_day_key" match="//DAY[vb:IsDateOfPeriod(string(@DATE))]" use="PLANENTRY/@TASKID"/>
  <xsl:key name="plan_entry_key" match="//DAY[vb:IsDateOfPeriod(string(@DATE))]/PLANENTRY" use="@TASKID"/>
	<xsl:template match="/">
		<xsl:variable name="projectTitle">
			<xsl:for-each select="//CATEGORY[@ID=$AffectedCategory]">
				<xsl:value-of select="@NAME"/>
			</xsl:for-each>
			<xsl:if test="$AffectedCategory = 0">
			{AllTasks}
			</xsl:if>
		</xsl:variable>
		<xsl:variable name="parentProjectTitle"> 
			<xsl:for-each select="//CATEGORY[@ID=$AffectedCategory]"> 
			<xsl:value-of select="vb:GetParentNames(.)"/>
			<xsl:value-of select="@NAME"/>
			</xsl:for-each> 
			<xsl:if test="$AffectedCategory = 0">
			{AllTasks}
			</xsl:if>
		</xsl:variable>
		<xsl:value-of select="vb:SetReportingPeriod($ReportingPeriodStart, $ReportingPeriodEnd)"/>
		<HTML>
			<HEAD>
				<META NAME="Report" CONTENT="{ProjectStatusReport}"/>
				<TITLE>{Report}: {ProjectStatusReport} [<xsl:value-of select="$projectTitle"/>]</TITLE>
				<STYLE ID="ReportStyle">
				<xsl:value-of select="$css"/>
				</STYLE>
			</HEAD>
			<BODY>
			<H2 align="center">{ProjectStatusReport}</H2>
			
			<xsl:for-each select="//PROPERTIES">
			<table border="0" cellpadding="2" cellspacing="0">
				<tr>
				<td class="righttitle">{Project}: </td>
				<td class="underlined"><xsl:value-of select="$projectTitle"/></td>
				</tr>
				<tr>
				<td class="righttitle">{Activities}: </td>
				<td class="underlined"><xsl:value-of select="vb:FormatThisPeriod()"/></td>
				</tr>
        <tr>
				<td class="righttitle">{TotalTime}: </td>
				<td class="underlined">
          <xsl:variable name="planEntriesListCat" select="key('plan_entry_key', //CATEGORY[@ID=$AffectedCategory]//TASK/@ID)"/>
          <xsl:variable name="workingHoursCat" select="vb:CalculateHours($planEntriesListCat)"/>
          <xsl:value-of select="$workingHoursCat"/> (<xsl:choose>
          <xsl:when test="//CATEGORY[@ID=$AffectedCategory]/@STATUS='1'">{Completed}</xsl:when>
          <xsl:otherwise>{InProgress}</xsl:otherwise>
        </xsl:choose>)</td>
				</tr>
			</table>
			</xsl:for-each>
			
			<br/>

			<TABLE BORDER="0" CELLPADDING="2" CELLSPACING="0" WIDTH="100%">
			<THEAD style="display: table-header-group"> 
			<TR>
			<TD class="leftHeadCell">{Task}</TD>
			<TD class="headCell">{Description}</TD>
			<TD class="headCell">{Status}/{Date}</TD>
      <TD class="headCell">{EstTime}</TD>
      <TD class="headCell">{TimeUsed}</TD>
			</TR>
			</THEAD>
			<TBODY>
			<xsl:choose>
			<xsl:when test="$AffectedCategory != 0">
			<xsl:for-each select="//CATEGORY[@ID=$AffectedCategory]">
				<xsl:value-of select="vb:SetBaseIntend(vb:GetIntendOnly(.))"/>
				<xsl:apply-templates select="."/>
        
        <xsl:variable name="planEntriesDaysList" select="key('task_day_key', .//TASK/@ID)"/>
        <xsl:variable name="nPlanEntries" select="count($planEntriesDaysList)"/>
        <xsl:if test="$nPlanEntries&gt;0">
        <TR>
			  <TD class="taskCell" colspan="5">&#160;</TD>
			  </TR>
        </xsl:if>
			</xsl:for-each>
			</xsl:when>
			<xsl:otherwise>
			<xsl:for-each select="ROOT/CATEGORY">
				<xsl:value-of select="vb:SetBaseIntend('')"/>
				<xsl:apply-templates select="."/>
			</xsl:for-each>
			</xsl:otherwise>
			</xsl:choose>
			</TBODY>
			</TABLE>
			
			<BR/>
			<table border="0" cellpadding="2" cellspacing="0">
			<tr><td colspan="2">&#160; </td></tr>
			<tr><td colspan="2">&#160; </td></tr>
			<tr>
			<td class="signetureCell" style="width: 300">{EmployeeSignature}</td>
			<td class="signetureCell">{Date}</td>
			</tr>
			<tr><td colspan="2">&#160; </td></tr>
			<tr>
			<td class="signetureCell">{ManagerSignature}</td>
			<td class="signetureCell">{Date}</td>
			</tr>
			</table>
				
			</BODY>
		</HTML>
	</xsl:template>
	
	<xsl:template match="CATEGORY">
		<xsl:variable name="planEntriesDaysList" select="key('task_day_key', .//TASK/@ID)"/>
		<xsl:variable name="nPlanEntries" select="count($planEntriesDaysList)"/>
    <xsl:variable name="planEntriesListCat" select="key('plan_entry_key', .//TASK/@ID)"/>
    <xsl:variable name="workingHoursCat" select="vb:CalculateHours($planEntriesListCat)"/>
    <xsl:if test="$nPlanEntries&gt;0">

    <TR>
				<TD class="categoryCell">
					<xsl:value-of select="vb:GetIntend(.)"/>
					<xsl:value-of select="@NAME"/>
				</TD>
				<TD class="categoryDescription">
					<xsl:value-of select="string(DESCRIPTION)"/>&#160;
				</TD>
				<TD class="categoryTotal">
          <xsl:choose>
            <xsl:when test="@STATUS='1'">{Completed}</xsl:when>
            <xsl:otherwise>{InProgress}</xsl:otherwise>
          </xsl:choose>
				</TD>
        <TD class="categoryTotal">
          <xsl:value-of select="vb:FormatNumberEx(js:ToDbl(string(sum(.//TASK/@ESTIMATION))))"/>
				</TD>
        <TD class="categoryTotal">
          <xsl:value-of select="$workingHoursCat"/>
				</TD>
			</TR>
			
				<xsl:for-each select="./TASK">
					<xsl:sort select="@NAME"/>
					<xsl:apply-templates select="."/>
				</xsl:for-each>
			<xsl:if test="./CATEGORY">
					<xsl:for-each select="./CATEGORY">
						<xsl:sort select="@NAME"/>
						<xsl:apply-templates select="."/>
					</xsl:for-each>
			</xsl:if>
    </xsl:if>
	</xsl:template>
  
	<xsl:template match="TASK">
    <xsl:variable name="planEntriesList" select="key('plan_entry_key', @ID)"/>
    <xsl:call-template name="ListPlanEntries">
      <xsl:with-param name="planEntriesList" select="$planEntriesList"/>
      <xsl:with-param name="taskName" select="@NAME"/>
    </xsl:call-template>
  </xsl:template>

  <xsl:template name="ListPlanEntries">
    <xsl:param name="planEntriesList"/>
    <xsl:param name="taskName"/>
    <xsl:for-each select="ms:node-set($planEntriesList)">
      <TR>
        <TD class="taskCell" colspan="2">
          <xsl:value-of select="vb:GetRecentIntend()"/>
          <xsl:choose>
            <xsl:when test="string(DESCRIPTION)">
              <xsl:value-of select="string(DESCRIPTION)"/>
            </xsl:when>
            <xsl:otherwise>
              <xsl:value-of select="$taskName"/>
            </xsl:otherwise>
          </xsl:choose>
        </TD>
        <TD class="freeTableCell">
          <xsl:value-of select="vb:FormatDate(string(../@DATE))"/>
        </TD>
        <TD class="freeTableCell">
          &#160;
        </TD>
        <TD class="freeTableCell">
          <xsl:value-of select="vb:HoursDiff(string(@STARTTIME), string(@ENDTIME))"/>
        </TD>
      </TR>
    </xsl:for-each>
  </xsl:template>
  
</xsl:stylesheet>
